@@ -63,11 +63,9 @@ newAchillesTable <- function(table, version = "5.3", cast = FALSE) {
 emptyAchillesTable <- function(cdm, name) {
   assertChoice(name, achillesTables(), length = 1)
   assertClass(cdm, "cdm_reference")
-  table <- fieldsTables |>
+  table <- omopTableFields(cdmVersion(cdm)) |>
     dplyr::filter(
-      .data$cdm_table_name == .env$name &
-        .data$type == "achilles" &
-        grepl(cdmVersion(cdm), .data$cdm_version)
+      .data$cdm_table_name == .env$name & .data$type == "achilles"
     ) |>
     emptyTable()
   cdm <- insertTable(cdm = cdm, name = name, table = table, overwrite = FALSE)
@@ -76,9 +74,8 @@ emptyAchillesTable <- function(cdm, name) {
 }
 
 castAchillesColumns <- function(table, name, version) {
-  cols <- fieldsTables |>
+  cols <- omopTableFields(version) |>
     dplyr::filter(
-      grepl(.env$version, .data$cdm_version) &
         .data$type == "achilles" & .data$cdm_table_name == .env$name) |>
     dplyr::select("cdm_field_name", "cdm_datatype") |>
     dplyr::mutate("cdm_datatype" = dplyr::case_when(
