@@ -108,7 +108,7 @@ constructCdmReference <- function(tables, cdmName, cdmVersion, cdmSource) {
 validateCdmReference <- function(cdm, soft) {
   # assert version
   version <- cdmVersion(cdm)
-  assertChoice(version, c("5.3", "5.4"), length = 1)
+  assertChoice(version, names(fieldsTables), length = 1)
 
   # assert source
   assertClass(cdmSource(cdm), "cdm_source")
@@ -277,6 +277,41 @@ checkPlausibleObservationDates <- function(x, call = parent.frame()) {
 
 
 }
+checkPerson <- function(cdm, call = parent.frame()) {
+  # check for table with persion_id or subject_id
+  tableName <- names(cdm)
+
+    tables <- tableName |>
+      purrr::map_lgl(\(x) {
+        id <- c("person_id", "subject_id")
+        id <- id[id %in% colnames(cdm[[x]])]
+        if (length(id) == 1) {
+          cdm[[x]] |>
+            dplyr::select("person_id" = dplyr::all_of(id)) |>
+            dplyr::anti_join(cdm$person, by = "person_id") |>
+            utils::head(1) |>
+            dplyr::tally() |>
+            dplyr::pull() > 0
+        } else {
+          FALSE
+        }
+      })
+
+    tables <- tableName[tables]
+
+
+    if (!is.null(tables)) {
+      cli::cli_warn(
+        message = c(
+          "There are person_id in the {tables} table but not in person table"
+        ),
+        call = call
+      )
+
+    }
+
+  return(invisible(cdm))
+}
 
 #' Get the name of a cdm_reference associated object
 #'
@@ -822,8 +857,8 @@ omopTables <- function(version = "5.3") {
 #' have.
 #'
 #' @param table Table to see required columns.
-#' @param onlyRequired Whether to include only required fields.
 #' @param version Version of the OMOP Common Data Model.
+#' @param onlyRequired deprecated
 #'
 #' @return Character vector with the column names
 #'
@@ -834,11 +869,13 @@ omopTables <- function(version = "5.3") {
 #'
 #' omopColumns("person")
 #'
-omopColumns <- function(table, onlyRequired = TRUE, version = "5.3") {
+omopColumns <- function(table, version = "5.3", onlyRequired = lifecycle::deprecated()) {
+  if (lifecycle::is_present(onlyRequired)) {
+    lifecycle::deprecate_soft("0.4.0", "omopColumns(onlyRequired = )")
+  }
   assertVersion(version = version)
   assertTableName(table = table, version = version, type = "cdm_table")
-  assertLogical(x = onlyRequired, length = 1)
-  getColumns(table = table, version = version, type = "cdm_table", required = onlyRequired)
+  getColumns(table = table, version = version, type = "cdm_table", required = FALSE)
 }
 
 #' Cohort tables that a cdm reference can contain in the OMOP Common Data
@@ -904,8 +941,8 @@ achillesTables <- function(version = "5.3"){
 #'
 #' @param table Table for which to see the required columns. One of
 #' "achilles_analysis", "achilles_results", or "achilles_results_dist".
-#' @param onlyRequired Whether to include only required fields.
 #' @param version Version of the OMOP Common Data Model.
+#' @param onlyRequired deprecated.
 #'
 #' @return Character vector with the column names
 #'
@@ -918,41 +955,33 @@ achillesTables <- function(version = "5.3"){
 #' achillesColumns("achilles_results")
 #' achillesColumns("achilles_results_dist")
 #' }
-achillesColumns <- function(table, onlyRequired = TRUE, version = "5.3") {
+achillesColumns <- function(table, version = "5.3", onlyRequired = lifecycle::deprecated()) {
+  if (lifecycle::is_present(onlyRequired)) {
+    lifecycle::deprecate_soft("0.4.0", "omopColumns(onlyRequired = )")
+  }
   assertVersion(version = version)
   assertTableName(table = table, version = version, type = "achilles")
-  assertLogical(x = onlyRequired, length = 1, null = TRUE)
-  getColumns(table = table, version = version, type = "achilles", required = onlyRequired)
+  getColumns(table = table, version = version, type = "achilles", required = FALSE)
 }
 
 assertVersion <- function(version, call = parent.frame()) {
-  assertChoice(x = version, choices = c("5.3", "5.4"), call = call,
-               msg = "`version` must be a choice between 5.3 and 5.4; it can not contain NA; it can not be NULL.")
+  assertChoice(x = version, choices = names(fieldsTables), call = call)
 }
 assertTableName <- function(table, version, type, call = parent.frame()) {
   assertChoice(x = table, choices = tableChoice(version, type), call = call)
 }
 tableChoice <- function(version, type) {
-  fieldsTables$cdm_table_name[
-    grepl(version, fieldsTables$cdm_version) &
-      fieldsTables$type == type
-  ] |>
-    unique()
+  x <- omopTableFields(version)
+  unique(x$cdm_table_name[x$type == type])
 }
 getColumns <- function(table, version, type, required) {
+  x <- omopTableFields(version)
   if (isTRUE(required)) {
-    fieldsTables$cdm_field_name[
-      grepl(version, fieldsTables$cdm_version) &
-        fieldsTables$cdm_table_name == table &
-        fieldsTables$is_required == TRUE &
-        fieldsTables$type == type
+    x$cdm_field_name[
+        x$cdm_table_name == table & x$is_required == TRUE & x$type == type
     ]
   } else {
-    fieldsTables$cdm_field_name[
-      grepl(version, fieldsTables$cdm_version) &
-        fieldsTables$cdm_table_name == table &
-        fieldsTables$type == type
-    ]
+    x$cdm_field_name[x$cdm_table_name == table & x$type == type]
   }
 }
 
@@ -991,11 +1020,7 @@ emptyCdmReference <- function(cdmName, cdmVersion = NULL) {
 }
 
 emptyOmopTableInternal <- function(name, version = "5.3") {
-  fieldsTables |>
-    dplyr::filter(
-      .data$cdm_table_name == name &
-        .data$type == "cdm_table" &
-        grepl(.env$version, .data$cdm_version)
-    ) |>
+  omopTableFields(version) |>
+    dplyr::filter(.data$cdm_table_name == name & .data$type == "cdm_table") |>
     emptyTable()
 }
