@@ -20,8 +20,8 @@
 #' @param minCellCount Minimum count for suppression purposes.
 #' @param fileName Name of the file that will be created. Use \{cdm_name\} to
 #' refer to the cdmName of the objects and \{date\} to add the export date.
-#' @param path Path where to create the csv file.
-#'
+#' @param path Path where to create the csv file. It is ignored if fileName it
+#' is a full name with path included.
 #' @export
 #'
 exportSummarisedResult <- function(...,
@@ -33,27 +33,43 @@ exportSummarisedResult <- function(...,
   assertList(x = results, class = "summarised_result")
   assertCharacter(fileName, length = 1, minNumCharacter = 1)
   assertCharacter(path, length = 1, minNumCharacter = 1)
+
+  if (dirname(fileName) != ".") {
+    path <- dirname(fileName)
+    fileName <- basename(fileName)
+  }
   if (!dir.exists(path)) {
     cli::cli_abort("path: {path}, does not exist")
   }
-  if (tools::file_ext(fileName) != "csv") {
+
+  fileExt <- tools::file_ext(fileName)
+  if (fileExt == "") {
     fileName <- paste0(fileName, ".csv")
+  } else if (fileExt != "csv") {
+    cli::cli_warn("Only .csv extrension is allowed (.{fileExt} -> .csv).")
+    fileName <- paste0(tools::file_path_sans_ext(fileName), ".csv")
   }
 
   # bind and suppress
   results <- bind(...) |> suppress(minCellCount = minCellCount)
 
   # cdm name
-  cdmName <- results$cdm_name |> unique() |> paste0(collapse = "_")
-  fileName <- stringr::str_replace(string = fileName,
-                       pattern = "\\{cdm_name\\}",
-                       replacement = cdmName)
+  cdmName <- results$cdm_name |>
+    unique() |>
+    paste0(collapse = "_")
+  fileName <- stringr::str_replace(
+    string = fileName,
+    pattern = "\\{cdm_name\\}",
+    replacement = cdmName
+  )
 
   # date
   date <- format(Sys.Date(), format = "%Y_%m_%d") |> as.character()
-  fileName <- stringr::str_replace(string = fileName,
-                                   pattern = "\\{date\\}",
-                                   replacement = date)
+  fileName <- stringr::str_replace(
+    string = fileName,
+    pattern = "\\{date\\}",
+    replacement = date
+  )
 
   # to tibble + pivot settings
   x <- results |>
@@ -61,7 +77,8 @@ exportSummarisedResult <- function(...,
     dplyr::union_all(results |> pivotSettings() |> dplyr::as_tibble())
 
   utils::write.csv(
-    x, file = file.path(path, fileName), row.names = FALSE
+    x,
+    file = file.path(path, fileName), row.names = FALSE
   )
 }
 
@@ -132,8 +149,7 @@ variableTypes <- function(table) {
   return(x)
 }
 assertClassification <- function(x) {
-  switch (
-    x,
+  switch(x,
     "chr" = "character",
     "fct" = "character",
     "ord" = "character",
