@@ -8,10 +8,8 @@ test_that("test validateNameArgument", {
   expect_warning(expect_warning(expect_identical(
     "my_name", validateNameArgument("myName", list("my_name" = 1), validation = "warning")
   )))
-
   expect_no_error(validateNameArgument(name = NULL, null = TRUE))
   expect_error(validateNameArgument(name = NULL, null = FALSE))
-
 })
 
 test_that("test validateCohortIdArgument", {
@@ -28,7 +26,6 @@ test_that("test validateCohortIdArgument", {
 })
 
 test_that("test validateWindowArgument", {
-
   window <- c(0, 1)
   expect_no_error(validateWindowArgument(window))
   window <- list(c(0, 1), c(2, 3))
@@ -66,19 +63,15 @@ test_that("test validateWindowArgument", {
 
 test_that("test validateAgeGroup", {
   #test list
-  ageGroup = c(0, 18)
-
-  expect_error(validateAgeGroupArgument(ageGroup))
+  expect_error(validateAgeGroupArgument(c("1", "18")))
   ageGroup = list(c(0, 18))
   expect_no_error(validateAgeGroupArgument(ageGroup))
 
   #test name
   ageGroup = validateAgeGroupArgument(ageGroup)
-
   expect_true(names(ageGroup) == "age_group")
 
   # name multiple group
-
   ageGroup = list(list(c(0, 19)), list(c(0, 18)))
   ageGroup = validateAgeGroupArgument(ageGroup)
   expect_true(all(names(ageGroup) == c("age_group_1", "age_group_2")))
@@ -93,38 +86,36 @@ test_that("test validateAgeGroup", {
   expect_error(validateAgeGroupArgument(ageGroup, overlap = FALSE))
 
   # test multiple age group
-
   ageGroup = list(list(c(0, 19)), list(c(0, 18)))
-
-  expect_error(validateAgeGroupArgument(ageGroup, overlap = FALSE,
-                                        multipleAgeGroup = FALSE))
-
-  expect_no_error(validateAgeGroupArgument(ageGroup, overlap = FALSE,
-                                           multipleAgeGroup = TRUE))
-
+  expect_error(validateAgeGroupArgument(
+    ageGroup, overlap = FALSE, multipleAgeGroup = FALSE))
+  expect_no_error(validateAgeGroupArgument(
+    ageGroup, overlap = FALSE, multipleAgeGroup = TRUE))
 
   # null age group
+  expect_no_error(validateAgeGroupArgument(
+    ageGroup = NULL, overlap = FALSE, multipleAgeGroup = FALSE))
+  expect_error(validateAgeGroupArgument(
+    ageGroup = NULL, overlap = FALSE, null = FALSE, multipleAgeGroup = FALSE))
 
-
-
-  expect_no_error(validateAgeGroupArgument(ageGroup = NULL, overlap = FALSE,
-                                        multipleAgeGroup = FALSE))
-
-  expect_error(validateAgeGroupArgument(ageGroup = NULL, overlap = FALSE,
-                                        null = FALSE, multipleAgeGroup = FALSE))
-
-
-
-
-
-
-
+  # correct naming
+  x <- list(0, c(1, 19), c(20, 39), c(40, 59), c(60, 79), c(80, Inf)) |>
+    validateAgeGroupArgument()
+  expect_identical(
+    x,
+    list("age_group" = list(
+      "0 to 0" = c(0, 0), "1 to 19" = c(1, 19), "20 to 39" = c(20, 39),
+      "40 to 59" = c(40, 59), "60 to 79" = c(60, 79), "80 or above" = c(80, Inf)
+    ))
+  )
+  expect_identical(
+    validateAgeGroupArgument(c(0, Inf), ageGroupName = "my_age_group"),
+    list(my_age_group = list(overall = c(0L, Inf)))
+  )
 })
 
 test_that("test validateCdmArgument", {
 
-
-
   cdm_object <- 1
   class(cdm_object) <- c("cdm_reference")
   expect_no_error(
@@ -240,6 +231,42 @@ test_that("test validateCdmArgument", {
     )
     )
 
+  # warnings if clinical table contain person id not in person  table
+
+  cdm_object <- list(
+    "observation_period" = dplyr::tibble(
+      observation_period_id = c(1L,1L), person_id = c(1L,1L),
+      observation_period_start_date = c(as.Date("2000-01-01"),as.Date("2000-01-02")),
+      observation_period_end_date = c(as.Date("2000-01-01"),as.Date("2100-01-01")),
+      period_type_concept_id = c(0L,0L)
+    ),
+    "person" = dplyr::tibble(
+      person_id = c(1L,1L),
+      gender_concept_id = c(8507L,8507L),
+      year_of_birth = c(1991L,1992L)
+    ),
+    "condition_occurrence" = dplyr::tibble(
+      condition_occurrence_id = c(1L,2L),
+      person_id = c(8507L,8507L),
+      condition_start_date =  c(as.Date("2000-01-01"),as.Date("2000-01-02")),
+      condition_end_date = c(as.Date("2000-01-01"),as.Date("2100-01-01"))
+    ))
+
+  class(cdm_object) <- c("cdm_reference")
+
+  expect_no_warning(
+    validateCdmArgument(
+      cdm_object,
+      checkPerson = FALSE
+    )
+  )
+
+  expect_warning(
+    validateCdmArgument(
+      cdm_object,
+      checkPerson = TRUE
+    )
+  )
 
 })
 
@@ -251,8 +278,8 @@ test_that("test validateResults", {
     "result_type" = "summarised_characteristics",
     "package_name" = "PatientProfiles",
     "package_version" = "0.4.0",
-    "group_name" = "sex",
-    "group_level" = "male",
+    "group_name" = "cohort_name",
+    "group_level" = "cohort1",
     "strata_name" = "sex",
     "strata_level" = "male",
     "variable_name" = "Age group",
@@ -268,8 +295,45 @@ test_that("test validateResults", {
 
   expect_no_error(x |>
                     newSummarisedResult() |>
-                    validateResultArguemnt())
+                    validateResultArgument())
 
+})
 
+test_that("test isResultSuppressed",{
+  obj <- dplyr::tibble(
+    "result_id" = as.integer(1),
+    "cdm_name" = "mock",
+    "group_name" = "overall",
+    "group_level" = "overall",
+    "strata_name" = c(rep("overall", 6), rep("sex", 3)),
+    "strata_level" = c(rep("overall", 6), "male", "female", "female"),
+    "variable_name" = c("number records", "age_group", "age_group", "age_group", "age_group", "my_variable", "number records", "age_group", "age_group"),
+    "variable_level" = c(NA, "<50", "<50", ">=50", ">=50", NA, NA, "<50", "<50"),
+    "estimate_name" = c("count", "count", "percentage", "count", "percentage", "random", "count", "count", "percentage"),
+    "estimate_type" = c("integer", "integer", "percentage", "integer", "percentage", "numeric", "integer", "integer", "percentage"),
+    "estimate_value" = c("10", "5", "50", "3", "30", "1", "3", "12", "6"),
+    "additional_name" = "overall",
+    "additional_level" = "overall"
+  ) |>
+    newSummarisedResult(settings = dplyr::tibble(
+      "result_id" = as.integer(1),
+      "result_type" = "summarised_characteristics",
+      "package_name" = "omopgenerics",
+      "package_version" = as.character(utils::packageVersion("omopgenerics"))
+    ))
+
+  # Test for no min_cell_count column
+  expect_warning(isResultSuppressed(result = obj, minCellCount = 3))
+
+  result <- suppress(obj, minCellCount = 2)
+
+  # Test for correctly specified min_cell_count
+  expect_no_warning(isResultSuppressed(result = result, minCellCount = 2))
+
+  # Test for greater actual min_cell_count
+  expect_warning(isResultSuppressed(result = result, minCellCount = 1))
+
+  # Test for smaller actual min_cell_count
+  expect_warning(isResultSuppressed(result = result, minCellCount = 3))
 
 })
